@@ -7,7 +7,6 @@ from unittest import mock
 import json
 import os
 import pytest
-from sqlite_utils.utils import sqlite3, find_spatialite
 import textwrap
 
 from .utils import collapse_whitespace
@@ -792,34 +791,6 @@ def test_query_raw(db_path, content, is_binary):
         assert result.output == str(content)
 
 
-@pytest.mark.skipif(not find_spatialite(), reason="Could not find SpatiaLite extension")
-@pytest.mark.skipif(
-    not hasattr(sqlite3.Connection, "enable_load_extension"),
-    reason="sqlite3.Connection missing enable_load_extension",
-)
-@pytest.mark.parametrize("use_spatialite_shortcut", [True, False])
-def test_query_load_extension(use_spatialite_shortcut):
-    # Without --load-extension:
-    result = CliRunner().invoke(cli.cli, [":memory:", "select spatialite_version()"])
-    assert result.exit_code == 1
-    assert "no such function: spatialite_version" in result.output
-    # With --load-extension:
-    if use_spatialite_shortcut:
-        load_extension = "spatialite"
-    else:
-        load_extension = find_spatialite()
-    result = CliRunner().invoke(
-        cli.cli,
-        [
-            ":memory:",
-            "select spatialite_version()",
-            "--load-extension={}".format(load_extension),
-        ],
-    )
-    assert result.exit_code == 0, result.stdout
-    assert ["spatialite_version()"] == list(json.loads(result.output)[0].keys())
-
-
 def test_query_memory_does_not_create_file(tmpdir):
     owd = os.getcwd()
     try:
@@ -1247,7 +1218,7 @@ def test_drop_table_error():
         )
         assert 1 == result.exit_code
         assert 'Error: Table "t2" does not exist' == result.output.strip()
-        # Using --ignore supresses that error
+        # Using --ignore suppresses that error
         result = runner.invoke(
             cli.cli,
             ["drop-table", "test.db", "t2", "--ignore"],
@@ -1288,7 +1259,7 @@ def test_drop_view_error():
         )
         assert 1 == result.exit_code
         assert 'Error: View "t2" does not exist' == result.output.strip()
-        # Using --ignore supresses that error
+        # Using --ignore suppresses that error
         result = runner.invoke(
             cli.cli,
             ["drop-view", "test.db", "t2", "--ignore"],
@@ -2043,7 +2014,7 @@ def test_insert_detect_types(tmpdir, option_or_env_var):
         ]
 
     if option_or_env_var is None:
-        # Use environemnt variable instead of option
+        # Use environment variable instead of option
         with mock.patch.dict(os.environ, {"SQLITE_UTILS_DETECT_TYPES": "1"}):
             _test()
     else:
