@@ -9,7 +9,7 @@ from sqlite_utils.db import (
     Table,
     View,
 )
-from sqlite_utils.utils import sqlite3
+from sqlite_utils.utils import hash_record, sqlite3
 import collections
 import datetime
 import decimal
@@ -888,6 +888,32 @@ def test_insert_hash_id(fresh_db):
     assert 1 == dogs.count
 
 
+@pytest.mark.parametrize("use_table_factory", [True, False])
+def test_insert_hash_id_columns(fresh_db, use_table_factory):
+    if use_table_factory:
+        dogs = fresh_db.table("dogs", hash_id_columns=("name", "twitter"))
+        insert_kwargs = {}
+    else:
+        dogs = fresh_db["dogs"]
+        insert_kwargs = dict(hash_id_columns=("name", "twitter"))
+
+    id = dogs.insert(
+        {"name": "Cleo", "twitter": "cleopaws", "age": 5},
+        **insert_kwargs,
+    ).last_pk
+    expected_hash = hash_record({"name": "Cleo", "twitter": "cleopaws"})
+    assert id == expected_hash
+    assert dogs.count == 1
+    # Insert replacing a second time should not create a new row
+    id2 = dogs.insert(
+        {"name": "Cleo", "twitter": "cleopaws", "age": 6},
+        **insert_kwargs,
+        replace=True,
+    ).last_pk
+    assert id2 == expected_hash
+    assert dogs.count == 1
+
+
 def test_vacuum(fresh_db):
     fresh_db["data"].insert({"foo": "foo", "bar": "bar"})
     fresh_db.vacuum()
@@ -1089,3 +1115,37 @@ def test_create_table_sql(fresh_db, columns, expected_sql_middle):
     sql = fresh_db.create_table_sql("t", columns)
     middle = sql.split("(")[1].split(")")[0].strip()
     assert middle == expected_sql_middle
+
+
+def test_create(fresh_db):
+    fresh_db["t"].create(
+        {
+            "id": int,
+            "text": str,
+            "float": float,
+            "integer": int,
+            "bytes": bytes,
+        },
+        pk="id",
+        column_order=("id", "float"),
+        not_null=("float", "integer"),
+        defaults={"integer": 0},
+    )
+    assert fresh_db["t"].schema == (
+        "CREATE TABLE [t] (\n"
+        "   [id] INTEGER PRIMARY KEY,\n"
+        "   [float] FLOAT NOT NULL,\n"
+        "   [text] TEXT,\n"
+        "   [integer] INTEGER NOT NULL DEFAULT 0,\n"
+        "   [bytes] BLOB\n"
+        ")"
+    )
+
+
+def test_create_if_not_exists(fresh_db):
+    fresh_db["t"].create({"id": int})
+    # This should error
+    with pytest.raises(sqlite3.OperationalError):
+        fresh_db["t"].create({"id": int})
+    # This should not
+    fresh_db["t"].create({"id": int}, if_not_exists=True)
